@@ -2,7 +2,8 @@
 #
 # Tests for libxlsxwriter.
 #
-# Copyright 2014-2021, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
 #
 
 import base_test_class
@@ -45,3 +46,6 @@ class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
 
     def test_chart_column12(self):
         self.run_exe_test('test_chart_column12')
+
+    def test_chart_column13(self):
+        self.run_exe_test('test_chart_column13')
