@@ -2,7 +2,8 @@
 #
 # Tests for libxlsxwriter.
 #
-# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
 #
 
 import os
@@ -160,6 +161,9 @@ class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
     def test_image57(self):
         self.run_exe_test('test_image57')
 
+    def test_image58(self):
+        self.run_exe_test('test_image58')
+
     # Test in-memory image handling.
     def test_image81(self):
         self.run_exe_test('test_image81', 'image01.xlsx')
