@@ -2,7 +2,8 @@
 #
 # Tests for libxlsxwriter.
 #
-# Copyright 2014-2022, John McNamara, jmcnamara@cpan.org
+# SPDX-License-Identifier: BSD-2-Clause
+# Copyright 2014-2024, John McNamara, jmcnamara@cpan.org.
 #
 
 import base_test_class
@@ -21,3 +22,6 @@ class TestCompareXLSXFiles(base_test_class.XLSXBaseTest):
 
     def test_macro03(self):
         self.run_exe_test('test_macro03', 'macro03.xlsm')
+
+    def test_macro04(self):
+        self.run_exe_test('test_macro04', 'macro04.xlsm')
